@@ -1,9 +1,6 @@
 package Crate;
 
-use strict;
-use warnings;
-
-our $VERSION = '0.001';
+our $VERSION = '0.003';
 
 1;
 
@@ -153,6 +150,10 @@ Code::TidyAll
 
 Data::Validate::IP
 
+=item *
+
+Net::OpenSSH
+
 =back
 
 =head1 DESCRIPTION
